deeplake.core.index
===================
.. currentmodule:: deeplake.core.index

.. autoclass:: IndexEntry
    :special-members:
    :members:

.. autoclass:: Index
    :special-members:
    :members:

.. autofunction:: merge_slices
.. autofunction:: slice_at_int
.. autofunction:: slice_length